class ILIPercent:
    def __init__(self, weighted, unweighted):
        self.weighted = weighted
        self.unweighted = unweighted

class ILINetData:
    def __init__(self, week, ages, total_ili, total_patients, 
                percentages):
        self.week = week
        self.ages = ages
        self.total_ili = total_ili
        self.total_patients = total_patients
        self.percentages = percentages


class ILINet:
    def __init__(self, updated, source, data):
        self.updated = updated
        self.source = source
        self.stats = data


class USCLPercent:
    def __init__(self, positive_a, positive_b, total):
        self.positive_a = positive_a
        self.positive_b = positive_b
        self.total = total


class USCLTotal:
    def __init__(self, a, b, tests):
        self.type_a = a
        self.type_b = b
        self.tests = tests

class USCLData:
    def __init__(self, week, totals, percentages):
        self.week = week
        self.totals = totals
        self.percentages = percentages


class USCL:
    def __init__(self, updated, source, data):
        self.updated = updated
        self.source = source
        self.stats = data


class TypeA:
    def __init__(self, h3n2v, h1n1, h3, unable_to_subtype, subtyping_not_performed):
        self.h3n2v = h3n2v
        self.h1n1 = h1n1
        self.h3 = h3
        self.unable_to_subtype = unable_to_subtype
        self.subtyping_not_performed = subtyping_not_performed


class USPHLData:
    def __init__(self, week, a, b, bvic, byam, total_tests):
        self.week = week
        self.type_a = a
        self.type_b = b
        self.bvic = bvic
        self.byam = byam
        self.total_tests = total_tests


class USPHL:
    def __init__(self, updated, source, data):
        self.updated = updated
        self.source = source
        self.stats = data


from setuptools import setup

ver = '1.2.0'

with open('README.md', 'r') as f:
  long_desc = f.read()

setup(
  name = 'disease.py',
  packages = ['diseaseapi'],
  version = ver,
  license='MIT',
  description = 'An asynchronous wrapper for the Open Disease API written in Python.',
  long_description= long_desc,
  long_description_content_type = 'text/markdown',
  author = 'Rob Wainwright',
  author_email = 'apex@taka.moe',
  url = 'https://github.com/apex2504/disease.py',
  keywords = ['coronavirus', 'covid-19'],
  install_requires=[
          'aiohttp',
      ],
  classifiers=[
    'Development Status :: 5 - Production/Stable',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
)



def format_date(dt):
    """
    Outputs the date in a nice format; 01 Jan 1970 00:00
    """
    return dt.strftime('%d %b %Y %H:%M')

def parse_date(dt):
    """
    Split the datetime into individual parts, useful for formatting date yourself
    """
    return dt.year, dt.month, dt.day, dt.hour, dt.minute, dt.second #returns format YEAR, MONTH, DAY, HOUR, MINUTE, SECOND

def format_number(number):
    """
    Formats a number to a more readable format; 10000 -> 10,000
    """
    if isinstance(number, int):
        return '{:,d}'.format(number)
    if number is None:
        return 'Unknown'
    return '{:3.2f}'.format(number)
